Learn R Programming

apollo (version 0.3.9)

apollo_diagnostics: Print diagnostics for model inputs Prints diagnostic summaries for a model component, including choice summaries, availability summaries, and selected parameter or structure diagnostics depending on the model type.

Description

Print diagnostics for model inputs Prints diagnostic summaries for a model component, including choice summaries, availability summaries, and selected parameter or structure diagnostics depending on the model type.

Usage

apollo_diagnostics(inputs, modelType, apollo_inputs, data = TRUE, param = TRUE)

Value

Invisibly returns TRUE if no error happened during execution.

Arguments

inputs

List of settings

modelType

Character. Type of model. Supported values include "mnl", "nl", "cnl", "dft", "el", "fmnl", "normd", "ol", "op", "mdcev", "mdcnev" and "lc".

apollo_inputs

List of main inputs to the model estimation process. See apollo_validateInputs.

data

Boolean. TRUE for printing report related to dependent and independent variables. FALSE for not printing it. Default is TRUE.

param

Boolean. TRUE for printing report related to estimated parameters (e.g. model structure). FALSE for not printing it. Default is TRUE.