Learn R Programming

apollo (version 0.3.9)

apollo_setWorkDir: Automatically sets working directory to active file directory

Description

This function only works in RStudio. If called outside RStudio, it prints a message to screen saying that it could not set the working directory.

Usage

apollo_setWorkDir()

Arguments

Value

Invisibly returns TRUE if the working directory was set, and FALSE otherwise.