Checks consistency of the database with apollo_control, sorts it by
indivID, and adds an internal ID variable (apollo_sequence)
apollo_validateData(database, apollo_control, silent = FALSE)data.frame. Validated version of database.
data.frame. Data used by model.
List. Options controlling the running of the code. See apollo_validateInputs.
Boolean. TRUE to prevent the function from printing to the console. Default is FALSE.
This function should be called after calling apollo_validateControl. Observations are not sorted by this function. For panel data, all rows for the same individual must already be contiguous.