Learn R Programming

apollo (version 0.3.9)

apollo_varList: Lists variable names and definitions used inside a function

Description

Returns a list containing the names and definitions of variables in f, apollo_randCoeff and apollo_lcPars

Usage

apollo_varList(f, apollo_inputs)

Arguments

f

Function. Usually apollo_probabilities. The function is parsed to identify variable definitions.

apollo_inputs

List grouping most common inputs. Created by function apollo_validateInputs.

Returns a list containing the names and definitions of variables defined inside f, apollo_randCoeff and apollo_lcPars.

Details

It looks for variable definitions inside f, apollo_randCoeff, and apollo_lcPars. It returns them in a list.