Applies the delta method to calculate the standard errors of transformations of parameters.
apollo_deltaMethod(model, deltaMethod_settings)Model object. Estimated model object as returned by function apollo_estimate.
List of arguments. It must contain the following.
operation: Character. Function to calculate the delta method for. See details.
parName1: Character. Name of the first parameter.
parName2: Character. Name of the second parameter. Optional depending on operation.
multPar1: Numeric scalar. A value to scale parName1.
multPar2: Numeric scalar. A value to scale parName2.
Value, s.e. and t-ratio resulting from the operation.
apollo_deltaMethod supports the following five operations.
Calculates the s.e. of parName1 + parName2
Calculates the s.e. of parName1 - parName2 and parName2 - parName1
Calculates the s.e. of parName1/parName2 and parName2/parName1
Calculates the s.e. of exp(parName1)
If only parName1 is provided, it calculates the s.e. of
exp(parName1)/(1+exp(parName1)) and 1/(1+exp(parName1)).
If parName1 and parName2 are provided, it calculates
exp(par_i)/(1+exp(parName1)+exp(parName2)) for i=1, 2, and 3 (par_3 = 1).
Calculates the mean and s.d. of a lognormal distribution based on the mean (parName1) and s.d. (parName2) of the underlying normal.