Returns values for random parameters and class allocation probabilities in a latent class model model.
apollo_lcUnconditionals(model, apollo_probabilities, apollo_inputs)A list of scalar log-likelihood values. The first element corresponds to the whole model, followed by the model components where available. Returns NA if component-level output is not available.
Model object. Estimated model object as returned by function apollo_estimate.
Function. Returns probabilities of the model to be estimated. Must receive three arguments:
apollo_beta: Named numeric vector. Names and values of model parameters.
apollo_inputs: List containing options of the model. See apollo_validateInputs.
functionality: Character. Can be either "components", "conditionals", "estimate" (default), "gradient", "hessian", "output", "prediction", "preprocess", "raw", "report", "shares_LL", "validate" or "zero_LL".
List grouping most common inputs. Created by function apollo_validateInputs.