apollo_loadModel: Loads model from file
Description
Loads a previously estimated model object from a file.
Usage
apollo_loadModel(modelName)
Arguments
- modelName
Character. Name of the model to load.
Details
This function looks for a file named modelName_model.rds in the output directory, if available, and otherwise in the working directory. It loads the object contained in the file and returns it.