powered by
This function only works in RStudio. If called outside RStudio, it prints a message to screen saying that it could not set the working directory.
apollo_setWorkDir()
Invisibly returns TRUE if the working directory was set, and FALSE otherwise.
TRUE
FALSE