Returns a list containing the names and definitions of variables in f, apollo_randCoeff and apollo_lcPars
apollo_varList(f, apollo_inputs)Function. Usually apollo_probabilities. The function is parsed to identify variable definitions.
List grouping most common inputs. Created by function apollo_validateInputs.
Returns a list containing the names and definitions of variables defined inside f, apollo_randCoeff and apollo_lcPars.
It looks for variable definitions inside f, apollo_randCoeff, and apollo_lcPars. It returns
them in a list.